@@ -1,6 +1,6 @@
-PROJECT_NAME="Equilibrium object from shotfile"
+"""Equilibrium object from shotfile"""
 
-import sys, logging
+import logging
 import numpy as np
 from scipy.integrate import cumtrapz
 
@@ -10,8 +10,7 @@ logger = logging.getLogger('aug_sfutils.sf2equ')
 
 
 class EQU:
-    """
-    Reads the whols equilibrium shotfile
+    """Reads the whole equilibrium shotfile
     Reduces 1D profiles to within separatrix,
     Calculates a few useful derived quantities
     Accepts a time sub-interval via tbeg, tend keywords
@@ -174,10 +173,10 @@ class EQU:
     def read_ssq(self):
 
         """
-        Creating dictionary map_equ.equ_map().ssq, containing all 
-        SSQ parameters labelled with the corresponding SSQNAM.
+        Creating attributes corresponding to SSQNAM.
         Beware: in different shotfiles, for a given j0 
-        SSQ[j0, time] can represent a different variable 
+        SSQ[j0, time] can represent a different variable.
+        This routine handles it consistently.
         """
 
         ssqs   = self.sf.getobject('SSQ') # Time is second
