@@ -256,9 +256,10 @@ class SFREAD:
         logger.debug('TB %s %d %d %d', obj, otyp, sfo.length, dfmt)
         if otyp == 8 and sfo.length == 0:
             if sfo.tbase_type == 1: # PPG_prog, e.g. END:T-LM_END
-                dout = self.ppg_time(obj)
+                data = self.ppg_time(obj)
             else:   # ADC_intern, e.g. DCN:T-ADC-SL
-                dout = (np.arange(sfo.n_steps, dtype=np.float32) - sfo.n_pre)/sfo.s_rate
+                data = (np.arange(sfo.n_steps, dtype=np.float32) - sfo.n_pre)/sfo.s_rate
+            dout = sfobj.SFOBJ(data, sfho=sfo) # Add metadata
         else:
             if dfmt in sfdics.fmt2len.keys(): # char variable
                 dlen = sfdics.fmt2len[dfmt]
@@ -287,9 +288,8 @@ class SFREAD:
                 logger.debug('Before getts06 dfmt:%d addr:%d len:%d data1:%d, %d', dfmt, addr, bytlen, data[0], data[1])
                 dout = 1e-9*(data - self.getts06(obj))
                 logger.debug('%d',  self.getts06(obj))
-            else:
-                dout = sfobj.SFOBJ(data, sfho=sfo) # Add metadata
 
+            dout = sfobj.SFOBJ(data, sfho=sfo) # Add metadata
             dout.calib = False
 # Calibrated signals and signal groups
             if otyp in (6, 7):
@@ -303,7 +303,7 @@ class SFREAD:
         return dout
 
 
-    def ppg_time(self, tbobj):
+    def ppg_time(self, tbobj): # Bug MAG:27204
         """
         Returns the time-array in [s] for TB of type PPG_prog
         """
@@ -311,29 +311,36 @@ class SFREAD:
         for rel in self.getrelnames(tbobj):
             if self.sfh[rel].obj_type == 3:
                 ppg = self.getdevice(rel)
-                if 'PRETRIG' in ppg.keys():
-                    pretrig = ppg['PRETRIG']
-                if self.sfh[tbobj].n_pre > 0:
-                    if pretrig > 0:
+                npt = self.sfh[tbobj].n_pre
+                nsteps = self.sfh[tbobj].n_steps
+                if not 'PRETRIG' in ppg.keys():
+                    continue
+                if npt > 0:
+                    if ppg['PRETRIG'] > 0:
                         dt = ppg['RESOLUT'][15] * PPGCLOCK[ppg['RESFACT'][15]] + 1e-6
                     else:
                         dt = 0.
-                    start_time = -dt*ppg['PULSES'][0]
+                    start_time = -dt*npt #ppg['PULSES'][0]
                 else:
                     start_time = 0.
-                time_ppg = []
+                dtyp = sfdics.fmt2np[self.sfh[tbobj].data_format]
                 start_phase = start_time
+                if npt > 0:
+                    time_ppg = dt*np.arange(npt, dtype=dtyp) + start_phase
+                    start_phase = time_ppg[-1] + dt
+                else:
+                    time_ppg = []
                 for jphase in range(16):
                     if ppg['PULSES'][jphase] > 0:
                         dt = ppg['RESOLUT'][jphase]*PPGCLOCK[ppg['RESFACT'][jphase]]
-                        dtyp = sfdics.fmt2np[self.sfh[tbobj].data_format]
                         tb_phase = dt*np.arange(ppg['PULSES'][jphase], dtype=dtyp) + start_phase
                         time_ppg = np.append(time_ppg, tb_phase)
                         start_phase = time_ppg[-1] + dt
+                        logger.debug('Start time %d %d %d %d %.4f %.4f', jphase, ppg['PULSES'][jphase], ppg['RESOLUT'][jphase], ppg['RESFACT'][jphase], dt, start_phase)
                 if len(time_ppg) == 0:
                     return None
                 else:
-                    return time_ppg
+                    return time_ppg[:nsteps]
         return None
 
 
